@@ -137,6 +137,7 @@ void pool_start_query(POOL_QUERY_CONTEXT *query_context, char *query, int len, N
 		if (pool_config->memory_cache_enabled)
 			query_context->temp_cache = pool_create_temp_query_cache(query);
 		pool_set_query_in_progress();
+		query_context->skip_cache_commit = false;
 		session_context->query_context = query_context;
 		MemoryContextSwitchTo(old_context);
 	}
@@ -297,7 +298,7 @@ int pool_virtual_master_db_node_id(void)
 		return REAL_MASTER_NODE_ID;
 	}
 
-	if (sc->query_context)
+	if (sc->in_progress && sc->query_context)
 	{
 		int node_id = sc->query_context->virtual_master_node_id;
 
