@@ -1346,7 +1346,7 @@ void pool_pending_message_reset_previous_message(void)
 				(errmsg("pool_pending_message_reset_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message = NULL;
+	session_context->previous_message_exists = false;
 }
 
 /*
@@ -1360,11 +1360,13 @@ void pool_pending_message_set_previous_message(POOL_PENDING_MESSAGE *message)
 				(errmsg("pool_pending_message_set_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message = message;
+	session_context->previous_message_exists = true;
+	memcpy(&session_context->previous_message, message, sizeof(POOL_PENDING_MESSAGE));
 }
 
 /*
- * Get previous message.
+ * Get previous message. This actually returns the address of memory. Do not
+ * try to free using pool_pending_message_free_pending_message().
  */
 POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 {
@@ -1374,7 +1376,10 @@ POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 				(errmsg("pool_pending_message_get_previous_message: session context is not initialized")));
 		return NULL;
 	}
-	return session_context->previous_message;
+	if (session_context->previous_message_exists == false)
+		return NULL;
+
+	return &session_context->previous_message;
 }
 
 /*
@@ -1450,6 +1455,25 @@ POOL_PENDING_MESSAGE *pool_pending_message_find_lastest_by_query_context(POOL_QU
 	return NULL;
 }
 
+/*
+ * Get target backend id from pending message assuming that the destination for
+ * the pending message is one of primary or standby node.
+ */
+int pool_pending_message_get_target_backend_id(POOL_PENDING_MESSAGE *msg)
+{
+	int backend_id = -1;
+
+	if (msg->node_ids[0] != -1)
+		backend_id = msg->node_ids[0];
+	else if (msg->node_ids[1] != -1)
+		backend_id = msg->node_ids[1];
+	else
+		ereport(ERROR,
+				(errmsg("pool_pending_message_get_target_backend_id: no target backend id found")));
+
+	return backend_id;
+}
+
 /*
  * Dump whole pending message list
  */
