@@ -9,6 +9,7 @@
 # -j JDBC driver path
 # -m install (install pgpool-II and use that for tests) / noinstall : Default install
 # -s unix socket directory 
+# -d start pgpool with debug option
 
 dir=`pwd`
 MODE=install
@@ -33,8 +34,15 @@ function install_pgpool
 {
 	echo "creating pgpool-II temporary installation ..."
         PGPOOL_PATH=$dir/temp/installed
-        
-	make install -C $dir/../../ -e prefix=${PGPOOL_PATH}
+
+        test -d $log || mkdir $log
+
+	make install -C $dir/../../ -e prefix=${PGPOOL_PATH} >& $log/regression.log 2>&1
+
+	if [ $? != 0 ];then
+	    echo "make install failed"
+	    exit 1
+	fi
 	
 	echo "moving pgpool_setup to temporary installation path ..."
         cp $dir/../pgpool_setup ${PGPOOL_PATH}/pgpool_setup
@@ -49,13 +57,6 @@ function verify_pginstallation
 		echo "$0: cannot locate pg_config"
 		exit 1
 	fi
-
-	# PostgreSQL lib directory
-	PGLIB=`$PG_INSTALL_DIR/pg_config --libdir`
-	if [ -z $PGLIB ]; then
-		echo "$0: cannot locate pg_config"
-		exit 1
-	fi
 }
 
 function export_env_vars
@@ -118,6 +119,7 @@ function print_usage
 	printf "  -j   FILE                Postgres jdbc jar file path\n" >&2
 	printf "  -s   DIRECTORY           unix socket directory\n" >&2
 	printf "  -t   TIMEOUT             timeout value for each test (sec)\n" >&2
+	printf "  -d                       start pgpool with debug option\n" >&2
 	printf "  -?                       print this help and then exit\n\n" >&2
 	printf "Please read the README for details on adding new tests\n" >&2
 
@@ -125,7 +127,7 @@ function print_usage
 
 trap "echo ; exit 0" SIGINT SIGQUIT
 
-while getopts "p:m:i:j:b:s:t:?" OPTION
+while getopts "p:m:i:j:b:s:t:d?" OPTION
 do
   case $OPTION in
     p)  PG_INSTALL_DIR="$OPTARG";;
@@ -135,6 +137,7 @@ do
     b)  PGBENCH_PATH="$OPTARG";;
     s)  PGSOCKET_DIR="$OPTARG";;
     t)  TIMEOUT="$OPTARG";;
+    d)  export PGPOOLDEBUG="true";;
     ?)  print_usage
         exit 2;;
   esac
@@ -149,7 +152,7 @@ elif [ "$MODE" = "noinstall" ]; then
 	if [[ -n "$PGPOOL_INSTALL_PATH" ]]; then
 		PGPOOL_PATH=$PGPOOL_INSTALL_PATH
 	fi
-	export PGPOOL_SETUP=$dir/../pgpool_setup
+        export PGPOOL_SETUP=$dir/../pgpool_setup
 else
 	echo $MODE : Invalid mode
 	exit -1
